@@ -9,6 +9,7 @@ from datetime import datetime
 import splunklib.client as client
 import urllib3
 from urllib.parse import urlparse, urlencode, urlunparse, parse_qs
+import requests
 
 urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)
 
@@ -65,6 +66,45 @@ def process_event(helper, *args, **kwargs):
             helper.log_warn(f'Failed to extract field "{field}" from record="{event}"')
             return default
 
+    def normalize_tenants_scope(tenants_scope):
+        try:
+            if isinstance(tenants_scope, list):
+                scope_list = tenants_scope
+            elif isinstance(tenants_scope, str):
+                ts = tenants_scope.strip()
+                if ts == "" or ts == "*":
+                    scope_list = ["*"]
+                else:
+                    scope_list = [s.strip() for s in ts.split(",") if s.strip()]
+            else:
+                scope_list = ["*"]
+        except Exception:
+            scope_list = ["*"]
+        return scope_list
+
+    def get_maintenance_status(helper, server_uri, session_key):
+        try:
+            header = {
+                "Authorization": f"Splunk {session_key}",
+                "Content-Type": "application/json",
+            }
+            endpoint = f"{server_uri}/services/trackme/v2/maintenance/check_global_maintenance_status"
+            response = requests.get(endpoint, headers=header, verify=False, timeout=60)
+            response.raise_for_status()
+            data = response.json()
+            data["tenants_scope"] = normalize_tenants_scope(data.get("tenants_scope", "*"))
+            helper.log_info(f"maintenance_check response={json.dumps(data)}")
+            return data
+        except Exception as e:
+            helper.log_error(f"maintenance_check failed exception=\"{str(e)}\"")
+            return None
+
+    def tenant_in_scope(tenant_id, tenants_scope):
+        scope_list = normalize_tenants_scope(tenants_scope)
+        if "*" in scope_list:
+            return True
+        return tenant_id in scope_list
+
     def create_notable_record(event, drilldown_link, helper):
 
         # get properties
@@ -137,10 +177,25 @@ def process_event(helper, *args, **kwargs):
     # drilldown_earliest
     drilldown_earliest = helper.get_param("drilldown_earliest") or "-24h"
 
+    # Maintenance status (queried once)
+    maintenance_info = get_maintenance_status(helper, server_uri, session_key)
+
     # Loop through the events
     for event in helper.get_events():
 
         tenant_id = event["tenant_id"]
+
+        # If maintenance is active and the tenant is in scope, skip this event
+        try:
+            if maintenance_info and maintenance_info.get("maintenance"):
+                if tenant_in_scope(tenant_id, maintenance_info.get("tenants_scope", ["*"])):
+                    helper.log_info(
+                        f"maintenance active for tenant_id={tenant_id}, skipping trackme_notable event"
+                    )
+                    continue
+        except Exception:
+            # Fail-open per event
+            pass
         tenant_idx = trackme_idx_for_tenant(session_key, server_uri, tenant_id)
         tenant_trackme_notable_idx = tenant_idx["trackme_notable_idx"]
 
